/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.so.api;

import java.util.Iterator;
import java.util.ServiceLoader;
import java.util.logging.Logger;

import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.DuplicatedEmittableDefectException;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.DuplicatedSubscriptionObjectException;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.InvalidEmittableDefectNameException;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.InvalidSubscriptionObjectNameException;

/**
 * Subscription object registrator introspecting the class loader to find
 * available subscription objects.
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class SubscriptionObjectRegistration {

    private final static Logger LOG = Logger
            .getLogger(SubscriptionObjectRegistration.class.getName());

    public final static void registers(final SubscriptionObjectRegistror subscriptionObjectRegistror) {
        final ServiceLoader<SubscriptionObject> subscriptionObjectsLoader = ServiceLoader
                .load(SubscriptionObject.class);
        final Iterator<SubscriptionObject> subscriptionObjectsIterator = subscriptionObjectsLoader
                .iterator();
        while (subscriptionObjectsIterator.hasNext()) {
            try {
                final SubscriptionObject subscriptionObject = subscriptionObjectsIterator.next();
                subscriptionObjectRegistror.registersSubscriptionObjects(subscriptionObject);
                LOG.fine("Subscription object '" + subscriptionObject.getName() + "' registered.");
            } catch (final DuplicatedSubscriptionObjectException e) {
                // Subscription object already registered
                LOG.severe("Trying to register a subscription object already registered ('"
                        + e.getSubscriptionObject().getName() + "'). Ignored.");
            } catch (final DuplicatedEmittableDefectException e) {
                // Subscription object defect registered twice
                LOG.severe("Trying to register a defect ('"
                        + e.getEmittableDefect().getName()
                        + "') twice into a subscription object ('"
                        + e.getSubscriptionObject().getName() + "'). Ignored.");
            } catch (final InvalidSubscriptionObjectNameException e) {
                // Subscription object name is invalid
                LOG.severe("Trying to register a subscription object having an invalid name ('"
                        + e.getSubscriptionObject().getName() + "'). Ignored.");
            } catch (final InvalidEmittableDefectNameException e) {
                // Subscription object defect name is invalid
                LOG.severe("Trying to register a subscription object having a defect with an invalid name ('"
                        + e.getSubscriptionObject().getName()
                        + "', '"
                        + e.getEmittableDefect().getName() + "'). Ignored.");
            } catch (final IllegalArgumentException e) {
                // It's a bug
                LOG.severe("Trying to register a null subscription object. Ignored.");
            }
        }
    }

}
