/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.so.api;

import java.util.Map;

import org.ow2.petals.cli.api.shell.Shell;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.DuplicatedEmittableDefectException;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.DuplicatedSubscriptionObjectException;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.InvalidEmittableDefectNameException;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.InvalidSubscriptionObjectNameException;

/**
 * The interface of a subscription object registror, registering subscription
 * object.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface SubscriptionObjectRegistror {

    /**
     * Register a subscription object.
     * 
     * @param subscriptionObject
     *            The subscription object to register. Not <code>null</code> and
     *            its emittable defect list must be not <code>null</code>.
     * @throws IllegalArgumentException
     *             The subscription object is <code>null</code> or the
     *             subscription object has a <code>null</code> list of emittable
     *             defects.
     * @throws DuplicatedSubscriptionObjectException
     *             The subscription object is already defined
     * @throws DuplicatedEmittableDefectException
     *             A defect is registered twice in a subscription object.
     * @throws InvalidSubscriptionObjectNameException
     *             subscription object name is invalid
     * @throws InvalidEmittableDefectNameException
     *             A subscription object defect name is invalid
     */
    public void registersSubscriptionObjects(final SubscriptionObject subscriptionObject)
            throws DuplicatedSubscriptionObjectException, DuplicatedEmittableDefectException,
            InvalidSubscriptionObjectNameException, InvalidEmittableDefectNameException,
            IllegalArgumentException;

    /**
     * Get the available subscription objects
     * 
     * @return a set of subscription objects mapped with their name
     */
    public Map<String, SubscriptionObject> getSubscriptionObjects();

    /**
     * @return The shell in which the subscription object and defects will run
     */
    public Shell getShell();

}
